@@ -41,19 +41,16 @@ Glib::ustring Box_DB_Table::get_table_name()
   return m_strTableName;
 }
 
-void Box_DB_Table::init_db_details(const Glib::ustring& strTableName, const Glib::ustring& strWhereClause /* = "" */)
+void Box_DB_Table::init_db_details(const Glib::ustring& strTableName)
 {
   m_strTableName = strTableName;
-  m_strWhereClause = strWhereClause;
 
   fill_fields();
   fill_from_database();
 }
 
-void Box_DB_Table::refresh_db_details(const Glib::ustring& strWhereClause)
+void Box_DB_Table::refresh_db_details()
 {
-  m_strWhereClause = strWhereClause;
-
   fill_from_database();
 }
 
@@ -63,32 +60,18 @@ void Box_DB_Table::fill_fields()
 
 }
 
-Gnome::Gda::Value Box_DB_Table::get_entered_field_data(const Field& /* field */) const
+Gnome::Gda::Value Box_DB_Table::get_entered_field_data(const LayoutItem_Field& /* field */) const
 {
   //Override this to use Field::set_data() too.
 
   return Gnome::Gda::Value(); //null
 }
 
-void Box_DB_Table::set_entered_field_data(const Field& /* field */, const Gnome::Gda::Value& /* value */)
+void Box_DB_Table::set_entered_field_data(const LayoutItem_Field& /* field */, const Gnome::Gda::Value& /* value */)
 {
   //Override this.
 }
 
-bool Box_DB_Table::get_field(const Glib::ustring& name, Field& field) const
-{
-  type_vecFields::const_iterator iterFind = std::find_if( m_Fields.begin(), m_Fields.end(), predicate_FieldHasName<Field>(name) );
-  if(iterFind != m_Fields.end()) //If it was found:
-  {
-    field = *iterFind;
-    return true;
-  }
-  else
-  {
-    return false; //not found.
-  }
-}
-
 bool Box_DB_Table::get_field_primary_key_for_table(const Glib::ustring table_name, Field& field) const
 {
   const Document_Glom* document = get_document();
@@ -166,7 +149,7 @@ bool Box_DB_Table::get_fields_for_table_one_field(const Glib::ustring& table_nam
   //Initialize output parameter:
   Field result = Field();
 
-  type_vecFields fields =  get_fields_for_table(table_name);
+  type_vecFields fields = get_fields_for_table(table_name);
   type_vecFields::iterator iter = std::find_if(fields.begin(), fields.end(), predicate_FieldHasName<Field>(field_name));
   if(iter != fields.end()) //TODO: Handle error?
   {
