@@ -44,7 +44,14 @@ Dialog_Layout_List_Related::Dialog_Layout_List_Related(BaseObjectType* cobject,
     m_treeview_fields->set_model(m_model_fields);
 
     // Append the View columns:
-    m_treeview_fields->append_column( gettext("Field Name"), m_ColumnsFields.m_col_name );
+
+    // Append the View columns:
+    Gtk::TreeView::Column* column_name = Gtk::manage( new Gtk::TreeView::Column(gettext("Name")) );
+    m_treeview_fields->append_column(*column_name);
+
+    Gtk::CellRendererText* renderer_name = Gtk::manage(new Gtk::CellRendererText);
+    column_name->pack_start(*renderer_name);
+    column_name->set_cell_data_func(*renderer_name, sigc::mem_fun(*this, &Dialog_Layout_List_Related::on_cell_data_name));
 
     //Sort by sequence, so we can change the order by changing the values in the hidden sequence column.
     m_model_fields->set_sort_column(m_ColumnsFields.m_col_sequence, Gtk::SORT_ASCENDING);
@@ -86,7 +93,7 @@ Dialog_Layout_List_Related::~Dialog_Layout_List_Related()
 
 void Dialog_Layout_List_Related::set_document(const Glib::ustring& layout, Document_Glom* document, const Glib::ustring& parent_table_name, const Glib::ustring& relationship_name)
 {
-  type_vecFields empty_fields; //Just to satisfy the base class.
+  type_vecLayoutFields empty_fields; //Just to satisfy the base class.
   Dialog_Layout::set_document(layout, document, parent_table_name, empty_fields);
   //m_table_name is now actually the parent_table_name.
 
@@ -99,7 +106,7 @@ void Dialog_Layout_List_Related::set_document(const Glib::ustring& layout, Docum
 void Dialog_Layout_List_Related::update_ui(bool including_relationship_list)
 {
    m_modified = false;
-  
+
   //Update the tree models from the document
   Document_Glom* document = m_document;
   if(document)
@@ -109,36 +116,35 @@ void Dialog_Layout_List_Related::update_ui(bool including_relationship_list)
     {
       m_combo_relationship_name->clear_text();
       Document_Glom::type_vecRelationships vecRelationships = document->get_relationships(m_relationship.get_from_table());
-  
+
       for(Document_Glom::type_vecRelationships::iterator iter = vecRelationships.begin(); iter != vecRelationships.end(); ++iter)
       {
         m_combo_relationship_name->append_text(iter->get_name());
       }
     }
-      
+
     //Set the table name and title:
     m_combo_relationship_name->set_active_text(m_relationship.get_name()); 
-   
+
     m_entry_table_title->set_text( m_relationship.get_title() );
 
     Document_Glom::type_mapLayoutGroupSequence mapGroups = document->get_relationship_data_layout_groups_plus_new_fields(m_layout_name, m_relationship);
 
     //If no information is stored in the document, then start with something:
-    
+
     if(mapGroups.empty())
     {
       const Glib::ustring table_name = m_relationship.get_to_table();
-      type_vecFields table_fields = document->get_table_fields(table_name);
-      
+      Document_Glom::type_vecFields table_fields = document->get_table_fields(table_name);
+
       LayoutGroup group;
       group.set_name("main");
 
       guint field_sequence = 1; //0 means no sequence
-      for(type_vecFields::const_iterator iter = table_fields.begin(); iter != table_fields.end(); ++iter)
+      for(Document_Glom::type_vecFields::const_iterator iter = table_fields.begin(); iter != table_fields.end(); ++iter)
       {
         LayoutItem_Field item;
         item.set_name(iter->get_name());
-        item.set_table_name(table_name);
         item.m_sequence = field_sequence;
 
         group.add_item(item, field_sequence);
@@ -169,7 +175,7 @@ void Dialog_Layout_List_Related::update_ui(bool including_relationship_list)
           Gtk::TreeModel::iterator iterTree = m_model_fields->append();
           Gtk::TreeModel::Row row = *iterTree;
 
-          row[m_ColumnsFields.m_col_name] = item->get_name(); //item->m_field.get_name() is not filled-in yet.
+          row[m_ColumnsFields.m_col_layout_item] = *item;
           row[m_ColumnsFields.m_col_sequence] = field_sequence;
           ++field_sequence;
         }
@@ -237,30 +243,28 @@ void Dialog_Layout_List_Related::on_button_field_down()
 void Dialog_Layout_List_Related::save_to_document()
 {
   Dialog_Layout::save_to_document();
-  
+
   if(m_modified)
   {
     //Get the data from the TreeView and store it in the document:
 
     //Get the groups and their fields:
     Document_Glom::type_mapLayoutGroupSequence mapGroups;
-   
+
     //Add the fields to the one group:
     LayoutGroup others;
     others.set_name("main");
     others.m_sequence = 1;
-      
+
     guint field_sequence = 1; //0 means no sequence
     for(Gtk::TreeModel::iterator iterFields = m_model_fields->children().begin(); iterFields != m_model_fields->children().end(); ++iterFields)
     {
       Gtk::TreeModel::Row row = *iterFields;
 
-      const Glib::ustring field_name = row[m_ColumnsFields.m_col_name];
+      LayoutItem_Field item = row[m_ColumnsFields.m_col_layout_item];
+      const Glib::ustring field_name = item.get_name();
       if(!field_name.empty())
       {
-        LayoutItem_Field item;
-        item.set_name(field_name);
-        item.set_table_name(m_table_name);
         item.m_sequence = field_sequence;
 
         others.add_item(item, field_sequence); //Add it to the group:
@@ -279,7 +283,7 @@ void Dialog_Layout_List_Related::save_to_document()
         m_document->set_relationship_data_layout_groups(m_layout_name, m_relationship, mapGroups);
         m_modified = false;
       }
-      
+
       //Save the relationship title, which will be used elsewhere too:
       m_relationship.set_title(m_entry_table_title->get_text());
       m_document->set_relationship(m_table_name, m_relationship);
@@ -321,21 +325,21 @@ void Dialog_Layout_List_Related::on_button_add_field()
     if(dialog)
     {
       dialog->set_document(m_document, m_relationship.get_to_table());
+      dialog->set_transient_for(*this);
       int response = dialog->run();
       if(response == Gtk::RESPONSE_OK)
       {
         //Get the chosen field:
-        Field field;
+        LayoutItem_Field field;
         dialog->get_field_chosen(field);
 
         //Add the field details to the layout treeview:
         Gtk::TreeModel::iterator iter =  m_model_fields->append();
-      
+
         if(iter)
         {
           Gtk::TreeModel::Row row = *iter;
-          row[m_ColumnsFields.m_col_name] = field.get_name();
-          //row[m_model_fields->m_columns.m_col_title] = field.get_title();
+          row[m_ColumnsFields.m_col_layout_item] = field;
 
           //Scroll to, and select, the new row:
           Glib::RefPtr<Gtk::TreeView::Selection> refTreeSelection = m_treeview_fields->get_selection();
@@ -377,3 +381,32 @@ Glib::ustring Dialog_Layout_List_Related::get_relationship_name() const
 {
   return m_combo_relationship_name->get_active_text();
 }
+
+
+void Dialog_Layout_List_Related::on_cell_data_name(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter)
+{
+  //Set the view's cell properties depending on the model's data:
+  Gtk::CellRendererText* renderer_text = dynamic_cast<Gtk::CellRendererText*>(renderer);
+  if(renderer_text)
+  {
+    if(iter)
+    {
+      Gtk::TreeModel::Row row = *iter;
+
+      //Indicate that it's a field in another table.
+      const LayoutItem_Field item = row[m_ColumnsFields.m_col_layout_item]; //TODO_performance: Reduce copying.
+
+      Glib::ustring markup;
+
+      if(item.get_has_relationship_name())
+        markup = item.get_relationship_name() + "::";
+
+      markup += item.get_name();
+
+      renderer_text->property_markup() = markup;
+
+      renderer_text->property_editable() = false; //Names can never be edited.
+    }
+  }
+}
+
