@@ -114,7 +114,10 @@ void Dialog_FieldDefinition::set_field(const Field& field, const Glib::ustring&
     m_pDataWidget_DefaultValueSimple = 0;
   }
 
-  m_pDataWidget_DefaultValueSimple = Gtk::manage( new DataWidget(m_Field.get_glom_type(), gettext("Default Value")) );
+  LayoutItem_Field layout_item;
+  layout_item.m_field = m_Field;
+  layout_item.m_field.set_title(gettext("Default Value"));
+  m_pDataWidget_DefaultValueSimple = Gtk::manage( new DataWidget(layout_item, "") );
 
   Gtk::Label* pLabel = m_pDataWidget_DefaultValueSimple->get_label();
   if(!pLabel->get_text().empty())
@@ -140,7 +143,7 @@ void Dialog_FieldDefinition::set_field(const Field& field, const Glib::ustring&
      m_pCombo_LookupRelationship->append_text(iter->get_name(), iter->get_from_field());
    }
   }
-  
+
   Glib::ustring lookup_relationship_name;
   if(!disable_default_value)
     lookup_relationship_name = m_Field.get_lookup_relationship();
@@ -319,6 +322,7 @@ void Dialog_FieldDefinition::on_button_edit_calculation()
     {
       m_Field.set_calculation( m_pTextView_Calculation->get_buffer()->get_text() );
       dialog->set_field(m_Field, m_table_name);
+      //TODO: dialog.set_transient_for(*get_app_window());
       int response = dialog->run();
       if(response == Gtk::RESPONSE_OK)
       {
